#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SATURATE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SATURATE_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/saturate.hpp>

#endif
